# configure file: /etc/default/npdm
#
# ["DEFAULT"] section will be append to every other section
# don't user it.
#
# Copyright (c) 2024 Li Qiong <liqong@nfschina.com> 
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>

import configparser
import os
import shlex

cfgfile = "/etc/default/npdm"

cfgparse = configparser.ConfigParser()

cfgparse["GENERIC"] = {
    "Version": "1.4",
    "NoActEnable": "0",
    "LowActiveEnable": "0",
    "LogLevel": "info"
}

cfgparse["NOACT"] = {
    "Freeze": "",
    "LowActive": "",
    "CpuMax": "20000 500000",
    "OnBattery": "0",
    "Timeout": "150",
}

cfgparse["LOWACTIVE"] = {
    "BlackList": "",
    "CpuMax": "20000 1000000",
    "OnBattery": "0",
}

def merge_section_value(setion):
    value = []
    for k,v in cfgparse.items(setion):
        value.extend(v.split())
    return value

class Configure:
    def  __init__(self):
        curVer = float (cfgparse["GENERIC"]["Version"])

        cfgparse.read(cfgfile)

        self.noActEnable = int (cfgparse["GENERIC"]["NoActEnable"].strip())
        self.lowActiveEnable = int (cfgparse["GENERIC"]["LowActiveEnable"].strip())
        self.logLevel =  cfgparse["GENERIC"]["LogLevel"].strip()
        self.noAct = {}
        self.noAct["Freeze"] = shlex.split(cfgparse["NOACT"]["Freeze"].strip())
        self.noAct["LowActive"] = shlex.split(cfgparse["NOACT"]["LowActive"].strip())
        self.noAct["CpuMax"] = cfgparse["NOACT"]["CpuMax"].strip()
        self.noAct["OnBattery"] = int (cfgparse["NOACT"]["OnBattery"].strip())
        self.noAct["Timeout"] = int (cfgparse["NOACT"]["Timeout"].strip())

        self.lowActive = {}
        self.lowActive["BlackList"] = shlex.split(cfgparse["LOWACTIVE"]["BlackList"].strip())
        self.lowActive["CpuMax"] =  cfgparse["LOWACTIVE"]["CpuMax"].strip()
        self.lowActive["OnBattery"] = int (cfgparse["LOWACTIVE"]["OnBattery"].strip())

        localVer = float (cfgparse["GENERIC"]["Version"])
        if not os.path.exists(cfgfile) or curVer > localVer:
            with open(cfgfile, "w") as f:
                cfgparse.write(f)

if __name__ == '__main__':
    config = Configure()
    print(config.lowActive)
