# Process control: freeze or moderate
#
# Copyright (c) 2024 Li Qiong <liqong@nfschina.com>
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>

import os
import sys
import time

from pdm.log  import logger

cgroot = f"/sys/fs/cgroup"

class ProcControl:
    def  __init__(self,config):
        try:
            cpuset = 0
            if os.cpu_count() > 1:
                cpuset = os.cpu_count() - 1

            f = os.path.join(f"{cgroot}", "cgroup.subtree_control")
            with open(f, "w") as f:
                f.write("+cpu +cpuset +io")

            cgp = f"{cgroot}/npdm"
            os.makedirs(cgp, exist_ok=True)
            f = os.path.join(f"{cgp}", "cgroup.subtree_control")
            with open(f, "w") as f:
                f.write("+cpu +cpuset +io")

            os.makedirs(f"{cgp}/freeze", exist_ok=True)
            os.makedirs(f"{cgp}/noact", exist_ok=True)
            os.makedirs(f"{cgp}/lowactive", exist_ok=True)

            f = os.path.join(f"{cgp}/noact", "cpu.max")
            with open(f, "w") as f:
                f.write(config.noAct["CpuMax"])

            f = os.path.join(f"{cgp}/noact", "cpuset.cpus")
            with open(f, "w") as f:
                f.write(f"{cpuset}")

            f = os.path.join(f"{cgp}/lowactive", "cpu.max")
            with open(f, "w") as f:
                f.write(config.lowActive["CpuMax"])

            f = os.path.join(f"{cgp}/lowactive", "cpuset.cpus")
            with open(f, "w") as f:
                f.write(f"{cpuset}")

            f = os.path.join(f"{cgp}/freeze", "cgroup.freeze")
            with open(f, "w") as f:
                f.write("1")

            self.rootProcs = os.path.join(f"{cgroot}", "cgroup.procs")
            self.freezeProcs = os.path.join(f"{cgp}/freeze", "cgroup.procs")
            self.noactProcs = os.path.join(f"{cgp}/noact", "cgroup.procs")
            self.lowactvProcs = os.path.join(f"{cgp}/lowactive", "cgroup.procs")
        except Exception as e:
            logger.e(f"[ProcGroupInit] {e}")

    def setCpuMax(self, cg, cpumax):
        cgp = f"{cgroot}/npdm"
        f = os.path.join(f"{cgp}/{cg}", "cpu.max")
        with open(f, "w") as f:
            f.write(cpumax)

    def freeze(self, pid):
        with open(self.freezeProcs, "w") as f:
            f.write(str(pid))

    def lowerActiveByNoAct(self, pid):
        with open(self.noactProcs, "w") as f:
            f.write(str(pid))

    def lowerActive(self, pid):
        with open(self.lowactvProcs, "w") as f:
            f.write(str(pid))

    """ write only one pid at once, can't write seri"""
    def free(self, pid):
        with open(self.rootProcs, "w") as f:
            f.write(str(pid))

    def unfreezeAll(self):
        try:
            lines = []
            with open(self.freezeProcs, "r") as frz:
                lines = frz.readlines()
                for pid in lines:
                    self.free(int(pid))
                logger.d(f"unfreeze {lines}")
        except Exception as e:
            logger.e(f"[unfreezeAll] {e}")

    def unnoActAll(self):
        try:
            with open(self.noactProcs, "r") as f:
                lines = f.readlines()
                for pid in lines:
                    self.free(int(pid))
            logger.d(f"unnoactAll {lines}")
        except Exception as e:
            logger.e(f"unnoactAll : {e}")

    def unlowerActiveAll(self):
        try:
            with open(self.lowactvProcs, "r") as f:
                lines = f.readlines()
                for pid in lines:
                    self.free(int(pid))
            logger.d(f"unlowerActive {lines}")
        except Exception as e:
            logger.e(f"unlowerActive: {e}")

if __name__ == '__main__':
    logger.i("procontr testing..")
    procontr = ProcControl()
    procontr.freeze(2675)
    time.sleep(10)
    procontr.unfreezeAll()

