#!/bin/bash

PID_FILE="/tmp/npdm.pid"
LOG_FILE="/var/log/npdm.log"

if [ ! -f "$PID_FILE" ]; then
    echo "PID file does not exist. Is the daemon running?" | tee -a $LOG_FILE
    exit 0
fi

PID=$(cat "$PID_FILE")

if [ -z "$PID" ]; then
    echo "PID file is empty." | tee -a $LOG_FILE
    exit 1
fi

# Check if the process is running
if ps -p "$PID" > /dev/null; then
    echo "Killing process with PID: $PID"
    kill -SIGINT "$PID"
    sleep 1
    if [ ! -f "$PID_FILE" ]; then
        echo "Process $PID killed successfully." | tee -a $LOG_FILE
    else
        echo "Failed to kill process $PID, force termination" | tee -a $LOG_FILE
        kill -SIGTERM "$PID"
        rm "$PID_FILE"
    fi
else
    echo "No process found with PID: $PID" | tee -a $LOG_FILE
fi
